# -*- coding: utf-8 -*-
"""typing_extensions exports"""
from typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)

__all__ = (
    'Annotated',
    'AsyncContextManager',
    'AsyncGenerator',
    'AsyncIterable',
    'AsyncIterator',
    'Awaitable',
    'ChainMap',
    'ClassVar',
    'Concatenate',
    'ContextManager',
    'Coroutine',
    'Counter',
    'DefaultDict',
    'Deque',
    'Final',
    'IntVar',
    'Literal',
    'NewType',
    'NoReturn',
    'OrderedDict',
    'ParamSpec',
    'ParamSpecArgs',
    'ParamSpecKwargs',
    'Protocol',
    'SupportsIndex',
    'TYPE_CHECKING',
    'Text',
    'Type',
    'TypeAlias',
    'TypeGuard',
    'TypedDict',
    '__all_typing_extensions__',
    'final',
    'get_args',
    'get_origin',
    'get_type_hints',
    'overload',
    'runtime',
    'runtime_checkable',
)
__all_typing_extensions__ = __all__
