# -*- coding: utf-8 -*-
"""typing + typing_extensions + misc types/aliases"""
import typing

import typing_extensions

from xtyping._meta import __version__
from xtyping._typing import (
    IO,
    TYPE_CHECKING,
    AbstractSet,
    Any,
    AnyStr,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ByteString,
    Callable,
    ChainMap,
    ClassVar,
    Collection,
    Container,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Dict,
    FrozenSet,
    Generator,
    Generic,
    Hashable,
    ItemsView,
    Iterable,
    Iterator,
    KeysView,
    List,
    Mapping,
    MappingView,
    MutableMapping,
    MutableSequence,
    MutableSet,
    NamedTuple,
    NewType,
    Optional,
    Reversible,
    Sequence,
    Set,
    Sized,
    SupportsAbs,
    SupportsBytes,
    SupportsComplex,
    SupportsFloat,
    SupportsInt,
    SupportsRound,
    Text,
    Tuple,
    Type,
    TypeVar,
    Union,
    ValuesView,
    __all_typing__,
    cast,
    get_type_hints,
    no_type_check,
    no_type_check_decorator,
    overload,
)
from xtyping._typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    __all_typing_extensions__,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)
from xtyping.shed import (
    _DT,
    _R,
    _RT,
    _T,
    AF,
    DT,
    FALSE,
    FN,
    KT,
    RT,
    STDIN,
    STDIO,
    TRUE,
    VT,
    AnyCallable,
    AnyFunction,
    AnyIterable,
    AnyIterator,
    ArrayShape,
    ArrShape,
    Bytes,
    CmdArgsType,
    DictAny,
    DictAnyAny,
    DictFloat,
    DictFloatFloat,
    DictInt,
    DictIntInt,
    DictNumber,
    DictNumberNumber,
    DictStr,
    DictStrAny,
    DictStrInt,
    DictStrStr,
    El,
    Element,
    EnvMap,
    EnvType,
    F,
    Flint,
    FsPath,
    FsPathLike,
    FuncType,
    HrTime,
    IntStr,
    IterableAny,
    IterableFloat,
    IterableInt,
    IterableNumber,
    IterableStr,
    IterableT,
    JsonArrT,
    JsonDictT,
    JsonListT,
    JsonObjT,
    KeyT,
    KeyType,
    ListAny,
    ListFloat,
    ListInt,
    ListListStr,
    ListNumber,
    ListStr,
    ListT,
    N,
    NoneBytes,
    NoneStr,
    NoneStrBytes,
    NoneType,
    Null,
    Number,
    OptFloat,
    OptInt,
    OptionalFloat,
    OptionalInt,
    OptionalStr,
    OptStr,
    Path,
    PathLike,
    R,
    ReturnT,
    ReturnType,
    SetAny,
    SetFloat,
    SetInt,
    SetNumber,
    SetStr,
    SetT,
    ShapeType,
    StrBytes,
    StrEnum,
    StringEnum,
    StrIntFloat,
    T,
    T_co,
    T_contra,
    TupleStrs,
    TupleStrStr,
    Txt,
    V_co,
    ValT,
    ValType,
    VT_co,
    __all_shed__,
    null,
)

#
# __all__ = (
#     'TRUE',
#     'FALSE',
#     'AF',
#     'AbstractSet',
#     'Any',
#     'AnyCallable',
#     'AnyFunction',
#     'AnyIterable',
#     'AnyIterator',
#     'AnyStr',
#     'ArrShape',
#     'ArrayShape',
#     'AsyncContextManager',
#     'AsyncGenerator',
#     'AsyncIterable',
#     'AsyncIterator',
#     'Awaitable',
#     'ByteString',
#     'Bytes',
#     'Callable',
#     'ChainMap',
#     'ClassVar',
#     'CmdArgsType',
#     'Collection',
#     'Container',
#     'ContextManager',
#     'Coroutine',
#     'Counter',
#     'DT',
#     'DefaultDict',
#     'Deque',
#     'Dict',
#     'DictAny',
#     'DictAnyAny',
#     'DictFloat',
#     'DictFloatFloat',
#     'DictInt',
#     'DictIntInt',
#     'DictNumber',
#     'DictNumberNumber',
#     'DictStr',
#     'DictStrAny',
#     'DictStrInt',
#     'DictStrStr',
#     'El',
#     'Element',
#     'EnvMap',
#     'EnvType',
#     'F',
#     'FN',
#     'Final',
#     'Flint',
#     'FrozenSet',
#     'FsPath',
#     'FsPathLike',
#     'FuncType',
#     'Generator',
#     'Generic',
#     'Hashable',
#     'HrTime',
#     'IO',
#     'IntStr',
#     'ItemsView',
#     'Iterable',
#     'IterableAny',
#     'IterableFloat',
#     'IterableInt',
#     'IterableNumber',
#     'IterableStr',
#     'IterableT',
#     'Iterator',
#     'JsonArrT',
#     'JsonDictT',
#     'JsonListT',
#     'JsonObjT',
#     'KT',
#     'KeyT',
#     'KeyType',
#     'KeysView',
#     'List',
#     'ListAny',
#     'ListFloat',
#     'ListInt',
#     'ListListStr',
#     'ListNumber',
#     'ListStr',
#     'ListT',
#     'Literal',
#     'Mapping',
#     'MappingView',
#     'MutableMapping',
#     'MutableSequence',
#     'MutableSet',
#     'N',
#     'NamedTuple',
#     'NewType',
#     'NoReturn',
#     'NoneBytes',
#     'NoneStr',
#     'NoneStrBytes',
#     'NoneType',
#     'Null',
#     'Number',
#     'OptFloat',
#     'OptInt',
#     'OptStr',
#     'Optional',
#     'OptionalFloat',
#     'OptionalInt',
#     'OptionalStr',
#     'Path',
#     'PathLike',
#     'Protocol',
#     'R',
#     'RT',
#     'ReturnT',
#     'ReturnType',
#     'Reversible',
#     'STDIN',
#     'STDIO',
#     'Sequence',
#     'Set',
#     'SetAny',
#     'SetFloat',
#     'SetInt',
#     'SetNumber',
#     'SetStr',
#     'SetT',
#     'ShapeType',
#     'Sized',
#     'StrBytes',
#     'StrEnum',
#     'StrIntFloat',
#     'StringEnum',
#     'SupportsAbs',
#     'SupportsBytes',
#     'SupportsComplex',
#     'SupportsFloat',
#     'SupportsInt',
#     'SupportsRound',
#     'T',
#     'TYPE_CHECKING',
#     'T_co',
#     'T_contra',
#     'Text',
#     'Tuple',
#     'TupleStrStr',
#     'TupleStrs',
#     'Txt',
#     'Type',
#     'TypeAlias',
#     'TypeVar',
#     'TypedDict',
#     'Union',
#     'VT',
#     'VT_co',
#     'V_co',
#     'ValT',
#     'ValType',
#     'ValuesView',
#     '_DT',
#     '_R',
#     '_RT',
#     '_T',
#     '__all_shed__',
#     '__all_typing__',
#     '__all_typing_extensions__',
#     '__version__',
#     'cast',
#     'final',
#     'get_type_hints',
#     'no_type_check',
#     'no_type_check_decorator',
#     'null',
#     'overload',
#     'runtime_checkable',
#     'typing',
#     'typing_extensions',
#
#     'Annotated',
#     'AsyncContextManager',
#     'AsyncGenerator',
#     'AsyncIterable',
#     'AsyncIterator',
#     'Awaitable',
#     'ChainMap',
#     'ClassVar',
#     'Concatenate',
#     'ContextManager',
#     'Coroutine',
#     'Counter',
#     'DefaultDict',
#     'Deque',
#     'Final',
#     'IntVar',
#     'Literal',
#     'NewType',
#     'NoReturn',
#     'OrderedDict',
#     'ParamSpec',
#     'ParamSpecArgs',
#     'ParamSpecKwargs',
#     'Protocol',
#     'SupportsIndex',
#     'TYPE_CHECKING',
#     'Text',
#     'Type',
#     'TypeAlias',
#     'TypeGuard',
#     'TypedDict',
#     '__all_typing_extensions__',
#     'final',
#     'get_args',
#     'get_origin',
#     'get_type_hints',
#     'overload',
#     'runtime',
#     'runtime_checkable',
#     )


__all__ = (
    'AF',
    'AbstractSet',
    'Annotated',
    'Any',
    'AnyCallable',
    'AnyFunction',
    'AnyIterable',
    'AnyIterator',
    'AnyStr',
    'ArrShape',
    'ArrayShape',
    'AsyncContextManager',
    'AsyncGenerator',
    'AsyncIterable',
    'AsyncIterator',
    'Awaitable',
    'ByteString',
    'Bytes',
    'Callable',
    'ChainMap',
    'ClassVar',
    'CmdArgsType',
    'Collection',
    'Concatenate',
    'Container',
    'ContextManager',
    'Coroutine',
    'Counter',
    'DT',
    'DefaultDict',
    'Deque',
    'Dict',
    'DictAny',
    'DictAnyAny',
    'DictFloat',
    'DictFloatFloat',
    'DictInt',
    'DictIntInt',
    'DictNumber',
    'DictNumberNumber',
    'DictStr',
    'DictStrAny',
    'DictStrInt',
    'DictStrStr',
    'El',
    'Element',
    'EnvMap',
    'EnvType',
    'F',
    'FALSE',
    'FN',
    'Final',
    'Flint',
    'FrozenSet',
    'FsPath',
    'FsPathLike',
    'FuncType',
    'Generator',
    'Generic',
    'Hashable',
    'HrTime',
    'IO',
    'IntStr',
    'IntVar',
    'ItemsView',
    'Iterable',
    'IterableAny',
    'IterableFloat',
    'IterableInt',
    'IterableNumber',
    'IterableStr',
    'IterableT',
    'Iterator',
    'JsonArrT',
    'JsonDictT',
    'JsonListT',
    'JsonObjT',
    'KT',
    'KeyT',
    'KeyType',
    'KeysView',
    'List',
    'ListAny',
    'ListFloat',
    'ListInt',
    'ListListStr',
    'ListNumber',
    'ListStr',
    'ListT',
    'Literal',
    'Mapping',
    'MappingView',
    'MutableMapping',
    'MutableSequence',
    'MutableSet',
    'N',
    'NamedTuple',
    'NewType',
    'NoReturn',
    'NoneBytes',
    'NoneStr',
    'NoneStrBytes',
    'NoneType',
    'Null',
    'Number',
    'OptFloat',
    'OptInt',
    'OptStr',
    'Optional',
    'OptionalFloat',
    'OptionalInt',
    'OptionalStr',
    'OrderedDict',
    'ParamSpec',
    'ParamSpecArgs',
    'ParamSpecKwargs',
    'Path',
    'PathLike',
    'Protocol',
    'R',
    'RT',
    'ReturnT',
    'ReturnType',
    'Reversible',
    'STDIN',
    'STDIO',
    'Sequence',
    'Set',
    'SetAny',
    'SetFloat',
    'SetInt',
    'SetNumber',
    'SetStr',
    'SetT',
    'ShapeType',
    'Sized',
    'StrBytes',
    'StrEnum',
    'StrIntFloat',
    'StringEnum',
    'SupportsAbs',
    'SupportsBytes',
    'SupportsComplex',
    'SupportsFloat',
    'SupportsIndex',
    'SupportsInt',
    'SupportsRound',
    'T',
    'TRUE',
    'TYPE_CHECKING',
    'T_co',
    'T_contra',
    'Text',
    'Tuple',
    'TupleStrStr',
    'TupleStrs',
    'Txt',
    'Type',
    'TypeAlias',
    'TypeGuard',
    'TypeVar',
    'TypedDict',
    'Union',
    'VT',
    'VT_co',
    'V_co',
    'ValT',
    'ValType',
    'ValuesView',
    '_DT',
    '_R',
    '_RT',
    '_T',
    '__all_shed__',
    '__all_typing__',
    '__all_typing_extensions__',
    '__version__',
    'cast',
    'final',
    'get_args',
    'get_origin',
    'get_type_hints',
    'no_type_check',
    'no_type_check_decorator',
    'null',
    'overload',
    'runtime',
    'runtime_checkable',
    'typing',
    'typing_extensions',
)
print(tuple(sorted(set(__all__))))
